@@ -1,12 +1,12 @@
 package matchers
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
-	"github.com/aws/aws-sdk-go/service/cloudformation"
+	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/aws/aws-sdk-go-v2/service/cloudformation"
 )
 
 const (
@@ -14,13 +14,13 @@ const (
 )
 
 // stackExists checks to see if a CloudFormation stack exists
-func stackExists(stackName string, session *session.Session) (bool, error) {
-	cfn := cloudformation.New(session)
+func stackExists(stackName string, cfg aws.Config) (bool, error) {
+	cfn := cloudformation.NewFromConfig(cfg)
 
 	input := &cloudformation.ListStackResourcesInput{
 		StackName: aws.String(stackName),
 	}
-	_, err := cfn.ListStackResources(input)
+	_, err := cfn.ListStackResources(context.Background(), input)
 
 	if err != nil {
 		// Check if its a not found error
