@@ -526,6 +526,24 @@ func validateNodeGroupBase(np NodePool, path string) error {
 		return errors.Errorf("Inferentia instance types are not supported for %s", ng.AMIFamily)
 	}
 
+	if ng.CapacityReservation != nil {
+		if ng.CapacityReservation.CapacityReservationPreference != nil {
+			if ng.CapacityReservation.CapacityReservationTarget != nil {
+				return errors.New("only one of CapacityReservationPreference or CapacityReservationTarget may be specified at a time")
+			}
+
+			if *ng.CapacityReservation.CapacityReservationPreference != OpenCapacityReservation && *ng.CapacityReservation.CapacityReservationPreference != NoneCapacityReservation {
+				return fmt.Errorf(`accepted values include "open" and "none"; got "%s"`, *ng.CapacityReservation.CapacityReservationPreference)
+			}
+		}
+
+		if ng.CapacityReservation.CapacityReservationTarget != nil {
+			if ng.CapacityReservation.CapacityReservationTarget.CapacityReservationID != nil && ng.CapacityReservation.CapacityReservationTarget.CapacityReservationResourceGroupARN != nil {
+				return errors.New("only one of CapacityReservationID or CapacityReservationResourceGroupARN may be specified at a time")
+			}
+		}
+	}
+
 	return nil
 }
 
