@@ -6,13 +6,12 @@ import (
 	"strings"
 	"time"
 
+	"github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
 	"github.com/tidwall/gjson"
 	"github.com/tidwall/sjson"
 
-	cfn "github.com/aws/aws-sdk-go/service/cloudformation"
-
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/cfn/builder"
 	"github.com/weaveworks/eksctl/pkg/cfn/outputs"
@@ -39,12 +38,12 @@ func (c *StackCollection) createClusterTask(ctx context.Context, errs chan error
 	if err := stack.AddAllResources(ctx); err != nil {
 		return err
 	}
-	return c.createClusterStack(name, stack, errs)
+	return c.createClusterStack(ctx, name, stack, errs)
 }
 
 // DescribeClusterStack calls DescribeStacks and filters out cluster stack
-func (c *StackCollection) DescribeClusterStack() (*Stack, error) {
-	stacks, err := c.DescribeStacks()
+func (c *StackCollection) DescribeClusterStack(ctx context.Context) (*Stack, error) {
+	stacks, err := c.DescribeStacks(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -54,7 +53,7 @@ func (c *StackCollection) DescribeClusterStack() (*Stack, error) {
 	}
 
 	for _, s := range stacks {
-		if *s.StackStatus == cfn.StackStatusDeleteComplete {
+		if s.StackStatus == types.StackStatusDeleteComplete {
 			continue
 		}
 		if getClusterName(s) != "" {
@@ -68,14 +67,14 @@ func (c *StackCollection) DescribeClusterStack() (*Stack, error) {
 // their output values, and sets the Fargate pod execution role ARN to
 // the ClusterConfig. If there is no cluster stack found but a fargate stack
 // exists, use the output from that stack.
-func (c *StackCollection) RefreshFargatePodExecutionRoleARN() error {
+func (c *StackCollection) RefreshFargatePodExecutionRoleARN(ctx context.Context) error {
 	fargateOutputs := map[string]outputs.Collector{
 		outputs.FargatePodExecutionRoleARN: func(v string) error {
 			c.spec.IAM.FargatePodExecutionRoleARN = &v
 			return nil
 		},
 	}
-	stack, err := c.DescribeClusterStack()
+	stack, err := c.DescribeClusterStack(ctx)
 	if err != nil {
 		return err
 	}
@@ -91,7 +90,7 @@ func (c *StackCollection) RefreshFargatePodExecutionRoleARN() error {
 	}
 
 	//check if fargate role is in separate stack
-	stack, err = c.GetFargateStack()
+	stack, err = c.GetFargateStack(ctx)
 	if err != nil {
 		return err
 	}
@@ -110,7 +109,7 @@ func (c *StackCollection) AppendNewClusterStackResource(ctx context.Context, pla
 	//   is managed as part of the stack;
 	// - CloudFormation cannot yet upgrade EKS control plane itself;
 
-	currentTemplate, err := c.GetStackTemplate(name)
+	currentTemplate, err := c.GetStackTemplate(ctx, name)
 	if err != nil {
 		return false, errors.Wrapf(err, "error getting stack template %s", name)
 	}
@@ -122,7 +121,7 @@ func (c *StackCollection) AppendNewClusterStackResource(ctx context.Context, pla
 		return false, fmt.Errorf("unexpected template format of the current stack ")
 	}
 
-	if err := c.importServiceRoleARN(currentResources); err != nil {
+	if err := c.importServiceRoleARN(ctx, currentResources); err != nil {
 		return false, err
 	}
 
@@ -197,7 +196,7 @@ func (c *StackCollection) AppendNewClusterStackResource(ctx context.Context, pla
 		logger.Info("(plan) %s", describeUpdate)
 		return true, nil
 	}
-	return true, c.UpdateStack(UpdateStackOptions{
+	return true, c.UpdateStack(ctx, UpdateStackOptions{
 		StackName:     name,
 		ChangeSetName: c.MakeChangeSetName("update-cluster"),
 		Description:   describeUpdate,
@@ -206,8 +205,8 @@ func (c *StackCollection) AppendNewClusterStackResource(ctx context.Context, pla
 	})
 }
 
-func (c *StackCollection) importServiceRoleARN(resources gjson.Result) error {
-	s, err := c.DescribeClusterStack()
+func (c *StackCollection) importServiceRoleARN(ctx context.Context, resources gjson.Result) error {
+	s, err := c.DescribeClusterStack(ctx)
 	if err != nil {
 		return err
 	}
