@@ -1,13 +1,18 @@
 package eks_test
 
 import (
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/eks"
+	"context"
+
+	"github.com/aws/aws-sdk-go-v2/aws"
+	ekstypes "github.com/aws/aws-sdk-go-v2/service/eks/types"
+
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+
 	"github.com/pkg/errors"
+
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
-	pkg_eks "github.com/weaveworks/eksctl/pkg/eks"
+	"github.com/weaveworks/eksctl/pkg/eks"
 	"github.com/weaveworks/eksctl/pkg/eks/fakes"
 )
 
@@ -46,25 +51,25 @@ var _ = Describe("Fargate", func() {
 	Describe("DoCreateFargateProfiles", func() {
 		It("should create profiles", func() {
 			fakeClient.CreateProfileReturns(nil)
-			Expect(pkg_eks.DoCreateFargateProfiles(config, fakeClient)).To(Succeed())
+			Expect(eks.DoCreateFargateProfiles(context.Background(), config, fakeClient)).To(Succeed())
 		})
 
 		When("a profile already exists", func() {
 			BeforeEach(func() {
 				fakeClient.CreateProfileReturnsOnCall(0, nil)
-				Expect(pkg_eks.DoCreateFargateProfiles(config, fakeClient)).To(Succeed())
+				Expect(eks.DoCreateFargateProfiles(context.Background(), config, fakeClient)).To(Succeed())
 			})
 
 			It("should not error", func() {
-				fakeClient.CreateProfileReturnsOnCall(1, &eks.ResourceInUseException{})
-				Expect(pkg_eks.DoCreateFargateProfiles(config, fakeClient)).To(Succeed())
+				fakeClient.CreateProfileReturnsOnCall(1, &ekstypes.ResourceInUseException{})
+				Expect(eks.DoCreateFargateProfiles(context.Background(), config, fakeClient)).To(Succeed())
 			})
 		})
 
 		When("profile creation fails", func() {
 			It("should return the error", func() {
 				fakeClient.CreateProfileReturns(errors.New("omigod"))
-				Expect(pkg_eks.DoCreateFargateProfiles(config, fakeClient)).To(MatchError(ContainSubstring("omigod")))
+				Expect(eks.DoCreateFargateProfiles(context.Background(), config, fakeClient)).To(MatchError(ContainSubstring("omigod")))
 			})
 		})
 	})
