@@ -32,7 +32,7 @@ var _ = Describe("TokenGenerator", func() {
 			}, nil)
 			clock.NowReturns(time.Date(2022, 1, 1, 1, 1, 1, 1, time.UTC))
 			generator := eks.NewGenerator(provider.MockSTSPresigner(), clock)
-			token, err := generator.GetWithSTS(context.TODO(), "cluster-id")
+			token, err := generator.GetWithSTS(context.Background(), "cluster-id")
 			Expect(err).NotTo(HaveOccurred())
 			Expect(token.Token).To(Equal("k8s-aws-v1.aHR0cHM6Ly9leGFtcGxlLmNvbQ"))
 		})
@@ -42,7 +42,7 @@ var _ = Describe("TokenGenerator", func() {
 				fakeGenerator.PresignGetCallerIdentityReturns(nil, errors.New("nope"))
 				clock.NowReturns(time.Date(2022, 1, 1, 1, 1, 1, 1, time.UTC))
 				generator := eks.NewGenerator(provider.MockSTSPresigner(), clock)
-				_, err := generator.GetWithSTS(context.TODO(), "cluster-id")
+				_, err := generator.GetWithSTS(context.Background(), "cluster-id")
 				Expect(err).To(MatchError("failed to presign caller identity: nope"))
 			})
 		})
